setup.softinfo(N = 10, order = 2, warn = FALSE, ...)TRUE, require that the density be unimodal.floor (N * unimodallowertail) or
floor (N * unimodaluppertail) segments.N+1.
Bounds on epiparameters s[0] through s[N]. See
expepi for details. Default: -1000 for lower,
+1000 for upper.N. Lower and upper bounds on the linear coefficients
(ak0) and quadratic coefficients (akp) of the splines.TRUE,
require continuity, continuous differentiability,
or that the density be lower semi-continuous (lsc) or upper
semi-continuous (usc).N giving lower and upper bounds on the density estimate inside
segments.N + 1 giving lower and upper bounds on the density estimate
at segment end points.lowerdensityvalueSpecific[j,2] at
x = lowerdensityvalueSpecific[j,1] for each row j.KLDensity,
e.g. dnorm, and whose parameters are given as a list in
DLDensityParams, e.g. list (mean = 0, sd = 1)expepi